@@ -20,22 +20,6 @@
 #' @return 
 #' \code{eigen()} computes the eigenvalues, and eigenvectors if requested.  As
 #' 
-#' @examples
-#' \dontrun{
-#' # Save code in a file "demo.r" and run with 2 processors by
-#' # > mpiexec -np 2 Rscript demo.r
-#' 
-#' library(pbdDMAT, quiet = TRUE)
-#' init.grid()
-#' 
-#' x <- ddmatrix(1:9, 3, bldim=2)
-#' 
-#' y <- eigen(crossprod(x))
-#' y
-#' 
-#' finalize()
-#' }
-#' 
 #' @keywords Methods Linear Algebra
 #' @aliases eigen
 #' @name ddmatrix-eigen
@@ -52,6 +36,9 @@ setMethod("eigen", signature(x="ddmatrix"),
     if (x@dim[1L] != x@dim[2L])
       comm.stop("non-square matrix in 'eigen'")
     
+    if (x@bldim[1L] != x@bldim[2L])
+      comm.stop(paste0("eigen() requires a square blocking factor; have ", x@bldim[1L], "x", x@bldim[2L]))
+    
     if (missing(symmetric)) 
       symmetric <- isSymmetric(x)
     
