@@ -2,11 +2,6 @@
 
 ### Export Namespace does not use .First.lib() and .Last.lib(), but use
 ### .onLoad() and .onUnload().
-# .First.lib <- function(lib, pkg){
-# } # End of .First.lib().
-
-# .Last.lib <- function(libpath){
-# } # End of .Last.lib().
 
 .onLoad <- function(libname, pkgname){
   if(! is.loaded("spmd_initialize")){
@@ -20,18 +15,17 @@
     library.dynam("pbdSLAP", "pbdSLAP", libname)
   }
 
-#  if(! is.loaded("mpi_blacs_initialize")){
   if(! is.loaded("R_blacs_init")){
     library.dynam("pbdBASE", "pbdBASE", libname)
   }
+  
+  pbdMPI::pbd_opt(BLDIM=c(16, 16))
+  pbdMPI::pbd_opt(ICTXT=0)
 
-#  library.dynam("pbdDMAT", pkgname, libname)
   invisible()
-} # End of .onload().
+}
 
 .onUnload <- function(libpath){
-#  library.dynam.unload("pbdDMAT", libpath)
+  library.dynam.unload("pbdDMAT", libpath)
   invisible()
-} # End of .onUnload().
-
-
+}
